@@ -6,7 +6,6 @@ import {
   getCompiler,
   getErrors,
   getWarnings,
-  removeCache,
 } from "./helpers/index";
 
 describe('"exclude" option', () => {
@@ -24,8 +23,6 @@ describe('"exclude" option', () => {
         },
       }
     );
-
-    return removeCache();
   });
 
   it("matches snapshot for a single `exclude` value ({RegExp})", async () => {
