@@ -8,16 +8,11 @@ import {
   getCompiler,
   getErrors,
   getWarnings,
-  removeCache,
 } from "./helpers/index";
 
 describe('"filename" option', () => {
   let compiler;
 
-  beforeEach(() => {
-    return removeCache();
-  });
-
   it("show work", async () => {
     compiler = getCompiler(
       "./entry.js",
@@ -108,7 +103,41 @@ describe('"filename" option', () => {
     new CompressionPlugin({
       minRatio: 1,
       filename(info) {
-        return `[name][ext].gz${info.query}`;
+        const [, , query] = /^([^?#]*)(\?[^#]*)?(#.*)?$/.exec(info.filename);
+
+        return `[name][ext].gz${query || ""}`;
+      },
+    }).apply(compiler);
+
+    const stats = await compile(compiler);
+
+    expect(getAssetsNameAndSize(stats, compiler)).toMatchSnapshot("assets");
+    expect(getWarnings(stats)).toMatchSnapshot("warnings");
+    expect(getErrors(stats)).toMatchSnapshot("errors");
+  });
+
+  it("matches snapshot for custom function ({Function}) and custom algorithm ({Function})", async () => {
+    compiler = getCompiler(
+      "./entry.js",
+      {},
+      {
+        output: {
+          path: path.resolve(__dirname, "./outputs"),
+          filename: "[name].js?var=[hash]#hash",
+          chunkFilename: "[id].[name].js?ver=[hash]#hash",
+        },
+      }
+    );
+
+    new CompressionPlugin({
+      minRatio: 1,
+      filename(info) {
+        const [, , query] = /^([^?#]*)(\?[^#]*)?(#.*)?$/.exec(info.filename);
+
+        return `[name][ext].gz${query || ""}`;
+      },
+      algorithm(input, compressionOptions, callback) {
+        callback(null, input);
       },
     }).apply(compiler);
 
