@@ -1,8 +1,7 @@
-import { RawSource } from "webpack-sources";
-
 export default class CopyPluginWithAssetInfo {
   apply(compiler) {
     const plugin = { name: this.constructor.name };
+    const { RawSource } = compiler.webpack.sources;
 
     compiler.hooks.thisCompilation.tap(plugin, (compilation) => {
       compilation.hooks.additionalAssets.tap(plugin, () => {
