@@ -1,10 +1,3 @@
-import webpack from "webpack";
-
-// webpack 5 exposes the sources property to ensure the right version of webpack-sources is used
-const { ConcatSource } =
-  // eslint-disable-next-line global-require
-  webpack.sources || require("webpack-sources");
-
 export default class ExistingCommentsFile {
   constructor(options = {}) {
     this.options = options;
@@ -12,14 +5,13 @@ export default class ExistingCommentsFile {
 
   apply(compiler) {
     const plugin = { name: this.constructor.name };
+    const { ConcatSource, RawSource } = compiler.webpack.sources;
 
     compiler.hooks.thisCompilation.tap(plugin, (compilation) => {
       compilation.hooks.additionalAssets.tap(plugin, () => {
         // eslint-disable-next-line no-param-reassign
         compilation.assets[this.options.name] = new ConcatSource(
-          `function changed() {} ${
-            this.options.comment ? "/*! CHANGED */" : ""
-          }`,
+          new RawSource(this.options.content),
           compilation.assets[this.options.name]
         );
       });
