@@ -6,10 +6,10 @@ import getCompiler from "./getCompiler";
 import getErrors from "./getErrors";
 import getWarnings from "./getWarnings";
 import ModifyExistingAsset from "./ModifyExistingAsset";
+import EmitNewAsset from "./EmitNewAsset";
 import normalizeErrors from "./normalizeErrors";
 import readAsset from "./readAsset";
 import readsAssets from "./readAssets";
-import removeCache from "./removeCache";
 
 export {
   compile,
@@ -20,8 +20,8 @@ export {
   getErrors,
   getWarnings,
   ModifyExistingAsset,
+  EmitNewAsset,
   normalizeErrors,
   readAsset,
   readsAssets,
-  removeCache,
 };
